@@ -10,10 +10,10 @@
 #'
 #' @param x [any]\cr
 #'  Object to convert.
-#' @param ... [any]\cr
-#'  Additional arguments passed to \code{\link{assertIntegerish}}.
+#' @template na-handling
+#' @inheritParams checkInteger
+#' @inheritParams checkVector
 #' @template tol
-#' @template add
 #' @template var.name
 #' @return Converted \code{x}.
 #' @export
@@ -21,8 +21,8 @@
 #' asInteger(c(1, 2, 3))
 #' asCount(1)
 #' asInt(1)
-asInteger = function(x, ..., tol = sqrt(.Machine$double.eps), .var.name = vname(x), add = NULL) {
-  assertIntegerish(x, ..., tol = tol, .var.name = .var.name, add = add)
+asInteger = function(x, tol = sqrt(.Machine$double.eps), lower = -Inf, upper = Inf, any.missing = TRUE, all.missing = TRUE, len = NULL, min.len = NULL, max.len = NULL, unique = FALSE, names = NULL, .var.name = vname(x)) {
+  assertIntegerish(x, tol = tol, lower = lower, upper = upper, any.missing = any.missing, all.missing = all.missing, len = len, min.len = min.len, max.len = max.len, unique = unique, names = names, null.ok = FALSE, .var.name = .var.name)
   storage.mode(x) = "integer"
   x
 }
@@ -33,8 +33,8 @@ asInteger = function(x, ..., tol = sqrt(.Machine$double.eps), .var.name = vname(
 #'  Default is \code{FALSE}.
 #' @template na.ok
 #' @export
-asCount = function(x, na.ok = FALSE, positive = FALSE, tol = sqrt(.Machine$double.eps), .var.name = vname(x), add = NULL) {
-  assertCount(x, na.ok, positive, tol, .var.name = .var.name, add = add)
+asCount = function(x, na.ok = FALSE, positive = FALSE, tol = sqrt(.Machine$double.eps), .var.name = vname(x)) {
+  assertCount(x, na.ok, positive, tol, .var.name = .var.name)
   storage.mode(x) = "integer"
   x
 }
@@ -42,8 +42,8 @@ asCount = function(x, na.ok = FALSE, positive = FALSE, tol = sqrt(.Machine$doubl
 #' @rdname asInteger
 #' @template bounds
 #' @export
-asInt = function(x, na.ok = FALSE, lower = -Inf, upper = Inf, tol = sqrt(.Machine$double.eps), .var.name = vname(x), add = NULL) {
-  assertInt(x, na.ok, lower, upper, tol, .var.name = .var.name, add = add)
+asInt = function(x, na.ok = FALSE, lower = -Inf, upper = Inf, tol = sqrt(.Machine$double.eps), .var.name = vname(x)) {
+  assertInt(x, na.ok, lower, upper, tol, .var.name = .var.name)
   storage.mode(x) = "integer"
   x
 }
