@@ -3,10 +3,10 @@
 #' @templateVar fn Int
 #' @template x
 #' @template na-handling
-#' @param na.ok [\code{logical(1)}]\cr
-#'  Are missing values allowed? Default is \code{FALSE}.
+#' @template na.ok
 #' @template bounds
 #' @template tol
+#' @template null.ok
 #' @template checker
 #' @family scalars
 #' @useDynLib checkmate c_check_int
@@ -14,10 +14,14 @@
 #' @examples
 #' testInt(1)
 #' testInt(-1, lower = 0)
-checkInt = function(x, na.ok = FALSE, lower = -Inf, upper = Inf, tol = sqrt(.Machine$double.eps)) {
-  .Call(c_check_int, x, na.ok, lower, upper, tol)
+checkInt = function(x, na.ok = FALSE, lower = -Inf, upper = Inf, tol = sqrt(.Machine$double.eps), null.ok = FALSE) {
+  .Call(c_check_int, x, na.ok, lower, upper, tol, null.ok)
 }
 
+#' @export
+#' @rdname checkInt
+check_int = checkInt
+
 #' @export
 #' @include makeAssertion.R
 #' @template assert
