@@ -25,7 +25,7 @@ Rboolean any_missing_integerish(SEXP x) {
         case LGLSXP: return any_missing_logical(x);
         case INTSXP: return any_missing_integer(x);
         case REALSXP: return any_missing_double(x);
-        default: error("Error in any_missing_logical: x is not logical or numeric");
+        default: error("Error in any_missing_integerish: x is not logical or numeric");
     }
 }
 
@@ -99,18 +99,19 @@ Rboolean any_missing_frame(SEXP x) {
     return FALSE;
 }
 
-SEXP c_any_missing(SEXP x) {
-    Rboolean res;
+Rboolean any_missing(SEXP x) {
     switch(TYPEOF(x)) {
-        case LGLSXP:  res = any_missing_logical(x); break;
-        case INTSXP:  res = any_missing_integer(x); break;
-        case REALSXP: res = any_missing_double(x); break;
-        case CPLXSXP: res = any_missing_complex(x); break;
-        case STRSXP:  res = any_missing_string(x); break;
-        case NILSXP:  res = FALSE; break;
-        case VECSXP:  res = isFrame(x) ? any_missing_frame(x) : any_missing_list(x); break;
-        case RAWSXP:  res = FALSE; break;
+        case LGLSXP:  return any_missing_logical(x);
+        case INTSXP:  return any_missing_integer(x);
+        case REALSXP: return any_missing_double(x);
+        case CPLXSXP: return any_missing_complex(x);
+        case STRSXP:  return any_missing_string(x);
+        case NILSXP:  return FALSE;
+        case VECSXP:  return isFrame(x) ? any_missing_frame(x) : any_missing_list(x);
+        case RAWSXP:  return FALSE;
         default: error("Object of type '%s' not supported", type2char(TYPEOF(x)));
     }
-    return ScalarLogical(res);
+}
+SEXP c_any_missing(SEXP x) {
+    return ScalarLogical(any_missing(x));
 }
