@@ -5,8 +5,8 @@
 #include <R.h>
 #include <Rinternals.h>
 
-const char * guessType(SEXP);
 Rboolean isStrictlyNumeric(SEXP);
+Rboolean isAtomicVector(SEXP);
 Rboolean isRList(SEXP);
 R_len_t get_ncols(SEXP);
 R_len_t get_nrows(SEXP);
